/*
 * LensKit, a reference implementation of recommender algorithms.
 * Copyright 2010-2011 Regents of the University of Minnesota
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
package org.grouplens.common.slf4j.maven;

import org.apache.maven.plugin.logging.Log;
import org.apache.maven.plugin.logging.SystemStreamLog;
import org.slf4j.ILoggerFactory;
import org.slf4j.Logger;

/**
 * @author Michael Ekstrand <ekstrand@cs.umn.edu>
 *
 */
public class MavenLoggerFactory implements ILoggerFactory {
    private static MavenLoggerFactory instance = new MavenLoggerFactory();
    
    private InheritableThreadLocal<InheritableReference<Log>> log =
        new InheritableReference.ThreadLocal<Log>();
    
    public static MavenLoggerFactory getInstance() {
        return instance;
    }
    
    private InheritableReference<Log> logRef() {
        return log.get();
    }
    
    /**
     * Set the log to be used for this thread.
     * @param log The logger to be used on this thread (and all child threads),
     * until a new logger is set.
     */
    public static void setLog(Log log) {
        getInstance().logRef().set(log);
    }
    
    Log getLog() {
        Log l = logRef().get();
        if (l == null) {
            l = new SystemStreamLog();
            logRef().setDefault(l);
        }
        return l;
    }

    /* (non-Javadoc)
     * @see org.slf4j.ILoggerFactory#getLogger(java.lang.String)
     */
    @Override
    public Logger getLogger(String name) {
        return new MavenLogger(name, this);
    }

}
